<?php

/*
Plugin Name: Featured Podcast Widget
Version: 1.0.2
Plugin URI: http://www.richardfarrar.com/featured-podcast-widget-for-wordpress/
Description: Displays the excerpt and featured image from the latest post featuring a <strong>podcast</strong> with an embedded audio player.
Author: Richard Farrar
Author URI: http://www.richardfarrar.com/
License: GPL v3

Copyright (C) 2013, Silicon Bay Limited - http://www.siliconbay.co.uk/

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if (!defined('DB_NAME'))
{
	header('HTTP/1.0 403 Forbidden');
	die;
}

if (!defined('FP_URL'))
	define('FP_URL', plugin_dir_url( __FILE__ ));

class Featured_Podcast extends WP_Widget
{	
	protected $defaults;

	public function __construct()
	{
		// Set the default widget settings
		$this->defaults = array(
			'title'			=> '',
			'posts_cat'		=> '',
			'postid'		=> '',
			'showsummary'	=> 1,
			'showfeatured'	=> 1,
			//'playerwidth'	=> 290,
			'featuretype'	=> 'latest'
		);

		// Widget settings
		$widget_ops = array(
		'classname' => 'featuredpodcast',	// CSS classname for widget div
		'description' => 'Displays the latest / featured podcast with excerpt and player.'	// Description shown in the WP Admin on the widgets page
		);

		// Widget control settings
		$control_ops = array(
		'id_base' => 'featured-podcast',
		'width' => 250,
		'height' => 250
		);

		// Create the widget
		$this->WP_Widget('featured-podcast', 'Featured Podcast', $widget_ops, $control_ops);
	}


	// prints the form on the widgets page
	public function form ($instance)
	{

		// Merge with defaults
		$instance = wp_parse_args((array) $instance, $this->defaults);
	?>

	<p>
		<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
		<input type="text" name="<?php echo $this->get_field_name('title') ?>" id="<?php echo $this->get_field_id('title') ?> " value="<?php echo $instance['title'] ?>" size="25">
	</p>

<!--
	<p>
		<label for="<?php echo $this->get_field_id('playerwidth'); ?>">Player Width:</label>
		<input type="text" name="<?php echo $this->get_field_name('playerwidth') ?>" id="<?php echo $this->get_field_id('playerwidth') ?> " value="<?php echo $instance['playerwidth'] ?>" size="5"> px
	</p>
-->

	<p>
		<label for="<?php echo $this->get_field_id('showfeatured'); ?>">Show Featured Image:</label>
		<input type="checkbox" name="<?php echo $this->get_field_name('showfeatured') ?>" id="<?php echo $this->get_field_id('showfeatured') ?> " value="1" <?php checked($instance['showfeatured']) ?>>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('showsummary'); ?>">Show Summary:</label>
		<input type="checkbox" name="<?php echo $this->get_field_name('showsummary') ?>" id="<?php echo $this->get_field_id('showsummary') ?> " value="1" <?php checked($instance['showsummary']) ?>>
	</p>
	
	<p>
	<label for="<?php echo $this->get_field_id('posts_cat'); ?>">Podcast Category:</label>
	<?php
		$categories_args = array(
			'name'            => $this->get_field_name('posts_cat'),
			'selected'        => $instance['posts_cat'],
			'orderby'         => 'Name',
			'hierarchical'    => 1,
			'show_option_all' => 'All Categories',
			'hide_empty'      => '0'
		);
		wp_dropdown_categories( $categories_args ); ?>
	</p>

	<fieldset>
		<legend>Select which podcast episode you would like to display:</legend>
		<p>
			<input type="radio" name="<?php echo $this->get_field_name('featuretype'); ?>" id="<?php echo $this->get_field_id('featuretype'); ?>_val1" value="latest" <?php checked($instance['featuretype'], 'latest'); ?>/>
			<label for="<?php echo $this->get_field_id('featuretype'); ?>_val1">Latest Podcast from Category</label><br />
			<input type="radio" name="<?php echo $this->get_field_name( 'featuretype' ); ?>" id="<?php echo $this->get_field_id('featuretype'); ?>_val2" value="featured" <?php checked($instance['featuretype'], 'featured'); ?>/>
			<label for="<?php echo $this->get_field_id('featuretype'); ?>_val2">Featured Podcast (set id below)</label><br />

			<label for="<?php echo $this->get_field_id('postid'); ?>">Featured Post's ID:</label>
			<input type="text" name="<?php echo $this->get_field_name('postid') ?>" id="<?php echo $this->get_field_id('postid') ?> " value="<?php echo $instance['postid'] ?>" size="5">
		</p>
	</fieldset>


	<?php		
		echo '<p><b>';

		if (function_exists('powerpress_init'))
			echo '<img src="' . FP_URL . 'images/tick.png" width="16" height="16" alt="tick" />';
		else
			echo '<img src="' . FP_URL . 'images/cross.png" width="16" height="16" alt="x" />';

		echo ' PowerPress Installed: Ready to Go<br />';

		echo '</b></p>';

		echo '<p><b>Widget Shortcode:</b> <code>[featuredpodcast]</code></p>';
	}


	// used when the user saves their widget options
	public function update ($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['posts_cat'] = $new_instance['posts_cat'];
		$instance['postid'] = $new_instance['postid'];
		$instance['showsummary'] = $new_instance['showsummary'];
		$instance['showfeatured'] = $new_instance['showfeatured'];
		//$instance['playerwidth'] = $new_instance['playerwidth'];
		$instance['featuretype'] = $new_instance['featuretype'];

		return $instance;
	}


	// used when the sidebar calls in the widget
	public function widget ($args, $instance)
	{
		extract($args);

		// Merge with defaults
		$instance = wp_parse_args((array) $instance, $this->defaults);

		echo $before_widget;

		if (!empty($instance['title']))
			echo $before_title . apply_filters('widget_title', $instance['title'], $instance, $this->id_base) . $after_title;

		// retrieve post information from database
		if ($instance['featuretype'] == 'featured')
		{
			$query_args = array(
				'post__in'	=> array($instance['postid']),
				'showposts' => '1'
			);
		}
		else
		{
			$query_args = array(
				'post_type' => 'post',
				'cat'       => $instance['posts_cat'],
				'showposts' => '1',
				'orderby'   =>'date',
				'order'     => 'DESC'
			);
		}

		$featured_post = new WP_Query($query_args);

		if ($featured_post->have_posts())
		{
			while ($featured_post->have_posts())
			{
				$featured_post->the_post();

				// If selected, show featured image from the post
				if ($instance['showfeatured'])
					echo the_post_thumbnail();	// Show featured image from the post

				// Show hyperlinked post title
				printf('<h3><a href="%s" title="%s">%s</a></h3>', get_permalink(), the_title_attribute('echo=0'), get_the_title());

				// If selected, show excerpt from the post
				if ($instance['showsummary'])
					the_excerpt();				// Show excerpt from the post

				printf('<span class="fp-more"><a href="%s">[Read More...]</a></span>', get_permalink());
			}
		}

		if (function_exists('powerpress_init'))
		{
			echo '<span class="fp-player">';

			if ($instance['playerwidth'] > 0)
				$output_text = do_shortcode('[powerpress width="' . $instance['playerwidth'] . '"px]');
			else
				$output_text = do_shortcode('[powerpress]');

			echo $output_text;
			echo '</span>';
		}

		echo $after_widget;
		wp_reset_query();
	}
}


// Hook the widget up to WordPres
add_action('widgets_init', create_function('', 'return register_widget("Featured_Podcast");'));


// Add widget shortcode
add_shortcode('featuredpodcast', 'featuredpodcast_shortcode_func');

function featuredpodcast_shortcode_func($atts)
{
	// Configure defaults and extract the attributes into variables
	extract(shortcode_atts(array(
		'title'			=> 'title',
		'posts_cat'		=> 'posts_cat',
		'postid'		=> 'postid',
		'showsummary'	=> 'showsummary',
		'showfeatured'	=> 'showfeatured',
		'featuretype'	=> 'featuretype'
	), $atts));

	$args = array(
		'before_widget' => '<div class="fpshortcode widget">',
		'after_widget'  => '</div>'
	);

	ob_start();
	the_widget('Featured_Podcast', $atts, $args);	// Display the widget
	$output = ob_get_clean();

	return $output;
}
